%define anolis_release 2

Name:           gi-docgen
Version:        2023.1
Release:        %{anolis_release}%{?dist}
Summary:        Documentation tool for GObject-based libraries

# Based on the “Copyright and Licensing terms” in README.md, on the contents of
# .reuse/dep5, and on inspection of SPDX headers or other file contents with
# assistance from licensecheck.
#
# The entire source is (Apache-2.0 OR GPL-3.0-or-later) except the following files that are
# packaged or are used to generate packaged files:
#
# MIT:
#   - gidocgen/templates/basic/fzy.js
#   - gidocgen/templates/basic/solarized-{dark,light}.js
#
# CC0-1.0:
#   - gi-docgen.pc.in (from which gi-docgen.pc is generated)
#   - gidocgen/templates/basic/*.png
#   - docs/CODEOWNERS (-doc subpackage)
#   - examples/*.toml (-doc subpackage)
#
# Note that CC0-1.0 is allowed for content only; these files may reasonably be
# called content.
#
# Additionally, the following sources are under licenses other than (ASL 2.0 or
# GPLv3+), but are not packaged in any of the binary RPMs:
#
# CC0-1.0:
#   - .editorconfig (not installed)
#   - .gitlab-ci.yml (not installed)
#   - gi-docgen.doap (not installed)
#   - MANIFEST.in (not installed)
#   - pytest.ini (not installed)
#
# CC-BY-SA-3.0:
#   - docs/gi-docgen.{png,svg} (for HTML docs; not currently packaged)
#   - code-of-conduct.md (not installed)
#
# OFL-1.1:
#   - gidocgen/templates/basic/*.{woff,woff2} (removed in prep)
#
# GPL-2.0-or-later:
#   - test/gir/{Utility-1.0,Regress-1.0}.gir (not installed; test only)
#
# LGPL-2.0-or-later:
#   - test/gir/{GLib,GObject,Gio}-2.0.gir (not installed; test only)
#
# LGPL-2.0-or-later OR MPL-1.1:
#   - test/gir/cairo-1.0.gir (not installed; test only)
License:        (Apache-2.0 OR GPL-3.0-or-later) AND MIT AND CC0-1.0
URL:            https://gitlab.gnome.org/GNOME/gi-docgen
Source0:        https://download.gnome.org/sources/gi-docgen/2023/%{name}-%{version}.tar.xz

BuildArch:      noarch

BuildRequires:  meson >= 0.55.0
BuildRequires:  python3-devel
BuildRequires:  python3dist(jinja2)
BuildRequires:  python3dist(markdown) >= 3.2
BuildRequires:  python3dist(markupsafe)
BuildRequires:  python3dist(packaging)
BuildRequires:  python3dist(pip) >= 19
BuildRequires:  python3dist(pygments)
BuildRequires:  python3dist(setuptools) >= 40.8
BuildRequires:  python3dist(tomli)
BuildRequires:  python3dist(typogrify)
BuildRequires:  python3dist(wheel)

Requires:       python3dist(jinja2)
Requires:       python3dist(markdown) >= 3.2
Requires:       python3dist(markupsafe)
Requires:       python3dist(pygments)
Requires:       python3dist(tomli)
Requires:       python3dist(typogrify)

# Trivial fork of https://github.com/jhawthorn/fzy.js (looks like it was
# basically just wrapped in an IIFE). Given that modification, it’s not clear
# how we could unbundle it, either downstream or with some kind of upstream
# support.
#
# It’s not clear what version was used for the fork.
Provides:       bundled(js-fzy)

%description
GI-DocGen is a document generator for GObject-based libraries. GObject is the
base type system of the GNOME project. GI-Docgen reuses the introspection data
generated by GObject-based libraries to generate the API reference of these
libraries, as well as other ancillary documentation.

GI-DocGen is not a general purpose documentation tool for C libraries.

While GI-DocGen can be used to generate API references for most GObject/C
libraries that expose introspection data, its main goal is to generate the
reference for GTK and its immediate dependencies. Any and all attempts at
making this tool more generic, or to cover more use cases, will be weighted
heavily against its primary goal.

GI-DocGen is still in development. The recommended use of GI-DocGen is to add
it as a sub-project to your Meson build system, and vendor it when releasing
dist archives.

You should not depend on a system-wide installation until GI-DocGen is declared
stable.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

install -D -m 644 docs/gi-docgen.1 %{buildroot}%{_mandir}/man1/%{name}.1

%generate_compatibility_deps

%files
%license LICENSES/*.txt .reuse/dep5
%{_bindir}/gi-docgen
%{_mandir}/man1/gi-docgen.1*
%{_datadir}/pkgconfig/gi-docgen.pc
%{python3_sitelib}/gidocgen

%files doc
%doc CHANGES.md code-of-conduct.md CONTRIBUTING.md README.md

%changelog
* Thu Mar 23 2023 yuanhui <yuanhui@linux.alibaba.com> - 2023.1-2
- Remove some useless buildrequires
- Add doc and abi files

* Mon Jan 16 2023 Funda Wang <fundawang@yeah.net> - 2023.1-1
- New version 2023.1

* Thu Dec 8 2022 Funda Wang <fundawang@yeah.net> - 2022.2-1
- Import 2022.2
